Disclaimer
==========

See the `DISCLAIMER.md <https://github.com/DOI-USGS/hyswap/blob/main/DISCLAIMER.md>`_ file for disclaimer information.

License
=======

See the `LICENSE.md <https://github.com/DOI-USGS/hyswap/blob/main/LICENSE.md>`_ file for license information.
